==> freecad_0.20.2+dfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Test/Gui/Resources/translations/Test_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="17"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="32"/>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="44"/>
      <source>Select test name:</source>
      <translation>Seleccioni el nom del test:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="96"/>
      <source>&amp;Start</source>
      <translation>&amp;Inici</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="99"/>
      <source>Alt+S</source>
      <translation>Alt + S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="128"/>
      <source>&amp;Help</source>
      <translation>&amp;Ajuda</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="131"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="141"/>
      <source>&amp;About</source>
      <translation>&amp;Sobre</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="144"/>
      <source>Alt+A</source>
      <translation>Alt + A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="154"/>
      <source>&amp;Close</source>
      <translation>Tan&amp;ca</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="157"/>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="169"/>
      <source>Progress</source>
      <translation>Progrés</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="188"/>
      <source>Run:</source>
      <translation>Executa:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="205"/>
      <source>Failures:</source>
      <translation>Fallades:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="222"/>
      <source>Errors:</source>
      <translation>Errors:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="239"/>
      <source>Remaining:</source>
      <translation>Restant:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="259"/>
      <source>Failures and errors</source>
      <translation>Fallades i errors</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="275"/>
      <source>Description</source>
      <translation>Descripció</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="292"/>
      <source>Idle</source>
      <translation>Inactiu</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="155"/>
      <source>Help</source>
      <translation>Ajuda</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="155"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Introduïu el nom d'un objecte cridable que quan es cridi retorni un TestCase.
Feu clic a 'Començar' i s'executarà el test anteriorment produït. 

Feu doble clic a un error a la vista d'arbre per veure'n més informació, incloent-hi la traça de pila.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="167"/>
      <source>About FreeCAD UnitTest</source>
      <translation>Sobre FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="167"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest és part de FreeCAD i permet escriure Unit Tests per a mòduls propis.</translation>
    </message>
  </context>
</TS>

==> freecad_1.0.0+dfsg.orig.tar.xz: FreeCAD-1.0.0/src/Mod/Test/Gui/Resources/translations/Test_ca.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca" sourcelanguage="en">
  <context>
    <name>TestGui::UnitTest</name>
    <message>
      <location filename="../../UnitTest.ui" line="17"/>
      <source>FreeCAD UnitTest</source>
      <translation>FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="32"/>
      <source>Test</source>
      <translation>Test</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="44"/>
      <source>Select test name:</source>
      <translation>Seleccioni el nom del test:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="96"/>
      <source>&amp;Start</source>
      <translation>&amp;Inici</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="99"/>
      <source>Alt+S</source>
      <translation>Alt + S</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="128"/>
      <source>&amp;Help</source>
      <translation>&amp;Ajuda</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="131"/>
      <source>F1</source>
      <translation>F1</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="141"/>
      <source>&amp;About</source>
      <translation>&amp;Sobre</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="144"/>
      <source>Alt+A</source>
      <translation>Alt + A</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="154"/>
      <source>&amp;Close</source>
      <translation>Tan&amp;ca</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="157"/>
      <source>Alt+C</source>
      <translation>Alt+C</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="169"/>
      <source>Progress</source>
      <translation>Progrés</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="188"/>
      <source>Run:</source>
      <translation>Executa:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="205"/>
      <source>Failures:</source>
      <translation>Fallades:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="222"/>
      <source>Errors:</source>
      <translation>Errors:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="239"/>
      <source>Remaining:</source>
      <translation>Restant:</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="259"/>
      <source>Failures and errors</source>
      <translation>Fallades i errors</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="275"/>
      <source>Description</source>
      <translation>Descripció</translation>
    </message>
    <message>
      <location filename="../../UnitTest.ui" line="292"/>
      <source>Idle</source>
      <translation>Inactiu</translation>
    </message>
  </context>
  <context>
    <name>TestGui::UnitTestDialog</name>
    <message>
      <location filename="../../UnitTestImp.cpp" line="165"/>
      <source>Help</source>
      <translation>Ajuda</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="166"/>
      <source>Enter the name of a callable object which, when called, will return a TestCase.
Click 'start', and the test thus produced will be run.

Double click on an error in the tree view to see more information about it, including the stack trace.</source>
      <translation>Introduïu el nom d'un objecte cridable que quan es cridi retorni un TestCase.
Feu clic a 'Comença' i s'executarà el test anteriorment produït. 

Feu doble clic a un error a la vista d'arbre per veure'n més informació, incloent-hi la traça de pila.</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="179"/>
      <source>About FreeCAD UnitTest</source>
      <translation>Sobre FreeCAD UnitTest</translation>
    </message>
    <message>
      <location filename="../../UnitTestImp.cpp" line="180"/>
      <source>Copyright (c) Werner Mayer

FreeCAD UnitTest is part of FreeCAD and supports writing Unit Tests for ones own modules.</source>
      <translation>Copyright (c) Werner Mayer

FreeCAD UnitTest és part de FreeCAD i permet escriure Unit Tests per a mòduls propis.</translation>
    </message>
  </context>
</TS>
